@@ -19,7 +19,7 @@ class EnviarPedido(Enviar):
         self.envio_por_querystring = False
 
     def gerar_dados_de_envio(self):
-        notification_url = MERCADOPAGO_PREFERENCE_NOTIFICATION_URL.format(self.pedido.conta.id)
+        notification_url = MERCADOPAGO_PREFERENCE_NOTIFICATION_URL.format(self.pedido.conta_id)
         preferencia = Preferencia(
             auto_return="approved",
             notification_url=notification_url,
@@ -52,7 +52,7 @@ class EnviarPedido(Enviar):
             ),
             items=self.items
         )
-        parametros = ParametrosMercadoPago("mercadopago", id=self.pedido.conta.id)
+        parametros = ParametrosMercadoPago("mercadopago", id=self.pedido.conta_id)
         try:
             sponsor_id = int(parametros.sponsor_id)
         except (AttributeError, ValueError):
